KIWI - Next Generation
======================

.. |GitHub Action Code Style| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-code-style.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |GitHub Action Config Functions| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-config-functions.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |GitHub Action Documentation| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-documentation.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |GitHub Action Publish Pages| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-publish-pages.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |GitHub Action Publish PyPi| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-publish-to-pypi.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |GitHub Action Unit Types| image:: https://github.com/OSInside/kiwi/actions/workflows/ci-units-types.yml/badge.svg
   :target: https://github.com/OSInside/kiwi/actions
.. |Health| image:: https://app.codacy.com/project/badge/Grade/228f7e8cd15d448688a590c272ec3789
   :target: https://www.codacy.com/gh/OSInside/kiwi/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=OSInside/kiwi&amp;utm_campaign=Badge_Grade
.. |Doc| replace:: `Documentation <https://osinside.github.io/kiwi/>`__
.. |Installation| replace:: `Installation <https://osinside.github.io/kiwi/installation.html>`__
.. |Contributing| replace:: `Contributing <https://osinside.github.io/kiwi/contributing.html>`__
.. |IntegrationTesting| replace:: `Integration Testing <https://osinside.github.io/kiwi/integration_testing.html>`__
.. |Donate| image:: https://www.paypalobjects.com/en_US/i/btn/btn_donateCC_LG.gif
   :target: https://www.paypal.com/donate/?hosted_button_id=CYZY57A7Q4TCC

|GitHub Action Code Style| |GitHub Action Config Functions| |GitHub Action Documentation| |GitHub Action Publish Pages| |GitHub Action Publish PyPi| |GitHub Action Unit Types| |Health|

**KIWI, the OS image and appliance builder.**

* |Installation|

* |IntegrationTesting|

* |Contributing|

* |Doc|

KIWI has helped you in your work ? Even the smallest gift is
a way to help that we don't run out of coffee :)

|Donate|
